summary refs log tree commit diff
path: root/pkgs/top-level/release-cross.nix
diff options
context:
space:
mode:
authoraszlig <aszlig@redmoonstudios.org>2014-03-03 22:31:18 +0100
committeraszlig <aszlig@redmoonstudios.org>2014-03-03 22:38:48 +0100
commite64b342fa8fda783a7247e0469943ce728498004 (patch)
tree567a9c73e4fbb2137f9c714848d11287db7692b3 /pkgs/top-level/release-cross.nix
parentae0b5d6813362492e744b1ac10e21309bb4e238b (diff)
downloadnixlib-e64b342fa8fda783a7247e0469943ce728498004.tar
nixlib-e64b342fa8fda783a7247e0469943ce728498004.tar.gz
nixlib-e64b342fa8fda783a7247e0469943ce728498004.tar.bz2
nixlib-e64b342fa8fda783a7247e0469943ce728498004.tar.lz
nixlib-e64b342fa8fda783a7247e0469943ce728498004.tar.xz
nixlib-e64b342fa8fda783a7247e0469943ce728498004.tar.zst
nixlib-e64b342fa8fda783a7247e0469943ce728498004.zip
Use mingw-w64 for 32bit Windows builds as well.
Mingw(32) is rather poorly maintaned and has quite a lot of bugs. And
because our Windows cross builds were also poorly maintained and most of
the cross-tests were broken as well, I'm just taking this step and try
to switch to mingw-w64 for everything "cross Windows".

Signed-off-by: aszlig <aszlig@redmoonstudios.org>
Diffstat (limited to 'pkgs/top-level/release-cross.nix')
-rw-r--r--pkgs/top-level/release-cross.nix11
1 files changed, 5 insertions, 6 deletions
diff --git a/pkgs/top-level/release-cross.nix b/pkgs/top-level/release-cross.nix
index 6871567ca8d1..cef3d2dffbdb 100644
--- a/pkgs/top-level/release-cross.nix
+++ b/pkgs/top-level/release-cross.nix
@@ -140,11 +140,11 @@ in {
   crossUltraSparcLinux = mapTestOnCross crossSystem basic;
 }) // (
 
 /* Test some cross builds on mingw32 */
 let
   crossSystem = {
-      config = "i686-pc-mingw32";
-      arch = "x86";
+      config = "i686-w64-mingw32";
+      arch = "x86"; # Irrelevant
       libc = "msvcrt"; # This distinguishes the mingw (non posix) toolchain
       platform = {};
   };
@@ -161,11 +161,10 @@ in {
   };
 }) // (
 
-/* Test some cross builds on mingw-w64 */
+/* Test some cross builds on 64 bit mingw-w64 */
 let
   crossSystem = {
-      # That's the triplet they use in the mingw-w64 docs,
-      # and it's relevant for nixpkgs conditions.
+      # That's the triplet they use in the mingw-w64 docs.
       config = "x86_64-w64-mingw32";
       arch = "x86_64"; # Irrelevant
       libc = "msvcrt"; # This distinguishes the mingw (non posix) toolchain
@@ -140,11 +140,11 @@ in {
 }) // (
 
-/* Test some cross builds on mingw32 */
+/* Test some cross builds on 32 bit mingw-w64 */
 let
   crossSystem = {